@@ -28,26 +28,23 @@ import datetime
 import dateparser
 
 from .engine import Session
+from .errorssaver import ErrorsSaver
 from .includessaver import IncludesSaver
+from .likessaver import LikesSaver
 from .models import SearchTerm
 from .tweetsaver import TweetSaver
 from ..exceptions import MonthlyQuotaExceededError
 
 
-class ApiResponseSaver(IncludesSaver, TweetSaver):
+class ApiResponseSaver(IncludesSaver, ErrorsSaver, LikesSaver, TweetSaver):
     """Save a batch of data as returned by GetTweetsSearchAllDownloader.batches."""
 
-    def __init__(self, shutdown):
-        """Initialise an ApiResponseSaver instance."""
-        super().__init__(shutdown)
-        self.count = 0
-
-    def save_batch_of_tweets(self, batch, search_term=None):
+    def save_batch(self, batch, search_term=None, liked_tweet_id=None):
         """
         Save the data in `batch` to the database.
 
-        Expects `batch` to be a data dictionary returned from one of the
-        tweets endpoints.
+        Tries to figure out whether items in `batch["data"]` are
+        users or tweets.
         """
         earliest_tweet_created_at = datetime.datetime.now(datetime.timezone.utc)
 
@@ -60,34 +57,26 @@ class ApiResponseSaver(IncludesSaver, TweetSaver):
                         .first()
                     ) or session.add(SearchTerm(search_term=search_term))
 
+            if "title" in batch and batch["title"] == "UsageCapExceeded":
+                raise MonthlyQuotaExceededError()
+
+            if "includes" in batch:
+                self._save_includes(batch["includes"], session)
+
+            if "errors" in batch:
+                self._save_errors(batch["errors"], session)
+
             if "data" in batch:
-                if "includes" in batch["data"]:
-                    self._save_includes(batch["data"]["includes"], session)
-                for tweet in batch["data"]:
-                    if self.shutdown.is_set():
-                        break
-                    self._save_tweet(tweet, session, search_term)
-                    self.count += 1
-                    earliest_tweet_created_at = min(
-                        earliest_tweet_created_at, dateparser.parse(tweet["created_at"])
-                    )
-            else:
-                if "title" in batch and batch["title"] == "UsageCapExceeded":
-                    raise MonthlyQuotaExceededError()
+                if liked_tweet_id:
+                    self._save_likes(batch["data"], session, liked_tweet_id)
+                else:
+                    for item in batch["data"]:
+                        if "author_id" in item:
+                            self._save_tweet(item, session, search_term)
+                            earliest_tweet_created_at = min(
+                                earliest_tweet_created_at, dateparser.parse(item["created_at"])
+                            )
+                        elif "username" in item:
+                            self._save_user(item, session)
+
         return earliest_tweet_created_at
-
-    def save_batch_of_users(self, batch):
-        """
-        Save the data in `batch` to the database.
-
-        Expects `batch` to be a data dictionary returned from one of the
-        user endpoints
-        """
-        with Session() as session:
-            if "data" in batch:
-                if "includes" in batch["data"]:
-                    self._save_includes(batch["data"]["includes"], session)
-                for user in batch["data"]:
-                    if self.shutdown.is_set():
-                        break
-                    self._save_user(user, session)
