@@ -35,15 +35,13 @@ class PlaceSaver(BaseItemSaver):
     def _save_place(self, data, session):
         """Save a place to the database."""
         with session.begin():
-            place = session.get(Place, data["id"])
-            session.add(place)
+            place = session.get(Place, data["id"]) or Place(id=data["id"])
 
-            if place is None:
-                place = Place(
-                    id=data["id"],
-                    name=data["name"],
-                    full_name=data["fullname"]
-                )
+            if place.name is None:
+                session.add(place)
+
+                place.name = data["name"],
+                place.full_name = data["full_name"]
 
                 place.place_type = (
                     session.query(PlaceType)
