@@ -23,7 +23,9 @@ __all__ = [
     "IncompleteTweetFinderThread",
     "IncompleteTweetUpdaterThread",
     "IncompleteUserFinderThread",
-    "IncompleteUserUpdaterThread"
+    "IncompleteUserUpdaterThread",
+    "TweetsWithoutLikesFinderThread",
+    "TweetsWithoutLikesUpdaterThread"
 ]
 
 from .gettweetssearchalldownloaderthread import GetTweetsSearchAllDownloaderThread
@@ -31,3 +33,5 @@ from .incompletetweetfinderthread import IncompleteTweetFinderThread
 from .incompletetweetupdaterthread import IncompleteTweetUpdaterThread
 from .incompleteuserfinderthread import IncompleteUserFinderThread
 from .incompleteuserupdaterthread import IncompleteUserUpdaterThread
+from .tweetswithoutlikesfinderthread import TweetsWithoutLikesFinderThread
+from .tweetswithoutlikesupdaterthread import TweetsWithoutLikesUpdaterThread
